@@ -1,6 +1,6 @@
 package Gearman::Util;
 use version;
-$Gearman::Util::VERSION = qv("1.130.002");
+$Gearman::Util::VERSION = qv("1.130.003");
 
 use strict;
 use warnings;
@@ -8,7 +8,7 @@ use warnings;
 # man errno
 # Resource temporarily unavailable
 # (may be the same value as EWOULDBLOCK) (POSIX.1)
-use Errno qw(EAGAIN);
+use POSIX qw(:errno_h);
 use Time::HiRes qw();
 use IO::Handle;
 
@@ -106,7 +106,7 @@ sub pack_res_command {
     return _pack_command("RES", @_);
 }
 
-=heade2 read_res_packet($sock, $err_ref, $timeout)
+=head2 read_res_packet($sock, $err_ref, $timeout)
 
 B<return> undef on closed socket or malformed packet
 
